==> dolfin_0.9.11.orig.tar.gz: dolfin-0.9.11/dolfin/mesh/UnitTriangle.cpp <==
// Copyright (C) 2010 Anders Logg
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
//
// First added:  2010-10-19
// Last changed: 2010-10-19

#include <dolfin/common/MPI.h>
#include "MeshPartitioning.h"
#include "MeshEditor.h"
#include "UnitTriangle.h"

using namespace dolfin;

//-----------------------------------------------------------------------------
UnitTriangle::UnitTriangle() : Mesh()
{
  // Receive mesh according to parallel policy
  if (MPI::is_receiver()) { MeshPartitioning::partition(*this); return; }

  // Open mesh for editing
  MeshEditor editor;
  editor.open(*this, CellType::triangle, 2, 2);

  // Create vertices
  editor.init_vertices(3);
  editor.add_vertex(0, 0, 0);
  editor.add_vertex(1, 1, 0);
  editor.add_vertex(2, 0, 1);

  // Create cells
  editor.init_cells(1);
  editor.add_cell(0, 0, 1, 2);

  // Close mesh editor
  editor.close();

  // Broadcast mesh according to parallel policy
  if (MPI::is_broadcaster()) { MeshPartitioning::partition(*this); return; }
}
//-----------------------------------------------------------------------------

==> dolfin_1.0-rc2.orig.tar.gz: dolfin-1.0-rc2/dolfin/mesh/UnitTriangle.cpp <==
// Copyright (C) 2010 Anders Logg
//
// This file is part of DOLFIN.
//
// DOLFIN is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// DOLFIN is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with DOLFIN. If not, see <http://www.gnu.org/licenses/>.
//
// First added:  2010-10-19
// Last changed: 2010-10-19

#include <dolfin/common/MPI.h>
#include "CellType.h"
#include "MeshPartitioning.h"
#include "MeshEditor.h"
#include "UnitTriangle.h"

using namespace dolfin;

//-----------------------------------------------------------------------------
UnitTriangle::UnitTriangle() : Mesh()
{
  // Receive mesh according to parallel policy
  if (MPI::is_receiver())
  {
    MeshPartitioning::build_distributed_mesh(*this);
    return;
  }

  // Open mesh for editing
  MeshEditor editor;
  editor.open(*this, CellType::triangle, 2, 2);

  // Create vertices
  editor.init_vertices(3);
  editor.add_vertex(0, 0, 0);
  editor.add_vertex(1, 1, 0);
  editor.add_vertex(2, 0, 1);

  // Create cells
  editor.init_cells(1);
  editor.add_cell(0, 0, 1, 2);

  // Close mesh editor
  editor.close();

  // Broadcast mesh according to parallel policy
  if (MPI::is_broadcaster())
  {
    MeshPartitioning::build_distributed_mesh(*this);
    return;
  }
}
//-----------------------------------------------------------------------------
